pub struct CachedBundle {
pub id: Uuid,
pub bundle: SignetEthBundle,
}Expand description
A bundle stored in the cache with its ID.
Contains a UUID identifier and the underlying SignetEthBundle.
Fields
id: UuidThe bundle id (a UUID)
bundle: SignetEthBundleThe bundle itself
Implementations
Sourceimpl CachedBundle
impl CachedBundle
Sourcepub const fn new(bundle: SignetEthBundle, id: Uuid) -> Self
pub const fn new(bundle: SignetEthBundle, id: Uuid) -> Self
Create a new cached bundle from a bundle and an id.
Sourcepub const fn from_bundle_and_id(bundle: SignetEthBundle, id: Uuid) -> Self
👎Deprecated: Use Self::new instead
pub const fn from_bundle_and_id(bundle: SignetEthBundle, id: Uuid) -> Self
Use Self::new instead
Create a new cached bundle from a bundle and an id.
Sourcepub fn into_bundle(self) -> SignetEthBundle
pub fn into_bundle(self) -> SignetEthBundle
Convert the cached bundle to a SignetEthBundle.
Sourcepub fn into_id(self) -> Uuid
pub fn into_id(self) -> Uuid
Convert the cached bundle to a uuid::Uuid.
Sourcepub const fn bundle(&self) -> &SignetEthBundle
pub const fn bundle(&self) -> &SignetEthBundle
The bundle itself.